'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def delete_object(Path=None):
    """
    Deletes an object at the specified path.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_object(
        Path='string'
    )
    
    
    :type Path: string
    :param Path: [REQUIRED]\nThe path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name>\n

    :rtype: dict
ReturnsResponse Syntax{}


Response Structure

(dict) --



Exceptions

MediaStoreData.Client.exceptions.ContainerNotFoundException
MediaStoreData.Client.exceptions.ObjectNotFoundException
MediaStoreData.Client.exceptions.InternalServerError


    :return: {}
    
    
    :returns: 
    MediaStoreData.Client.exceptions.ContainerNotFoundException
    MediaStoreData.Client.exceptions.ObjectNotFoundException
    MediaStoreData.Client.exceptions.InternalServerError
    
    """
    pass

def describe_object(Path=None):
    """
    Gets the headers for an object at the specified path.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_object(
        Path='string'
    )
    
    
    :type Path: string
    :param Path: [REQUIRED]\nThe path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name>\n

    :rtype: dict
ReturnsResponse Syntax{
    'ETag': 'string',
    'ContentType': 'string',
    'ContentLength': 123,
    'CacheControl': 'string',
    'LastModified': datetime(2015, 1, 1)
}


Response Structure

(dict) --
ETag (string) --The ETag that represents a unique instance of the object.

ContentType (string) --The content type of the object.

ContentLength (integer) --The length of the object in bytes.

CacheControl (string) --An optional CacheControl header that allows the caller to control the object\'s cache behavior. Headers can be passed in as specified in the HTTP at https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.9 .
Headers with a custom user-defined value are also accepted.

LastModified (datetime) --The date and time that the object was last modified.






Exceptions

MediaStoreData.Client.exceptions.ContainerNotFoundException
MediaStoreData.Client.exceptions.ObjectNotFoundException
MediaStoreData.Client.exceptions.InternalServerError


    :return: {
        'ETag': 'string',
        'ContentType': 'string',
        'ContentLength': 123,
        'CacheControl': 'string',
        'LastModified': datetime(2015, 1, 1)
    }
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_object(Path=None, Range=None):
    """
    Downloads the object at the specified path. If the object\xe2\x80\x99s upload availability is set to streaming , AWS Elemental MediaStore downloads the object even if it\xe2\x80\x99s still uploading the object.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_object(
        Path='string',
        Range='string'
    )
    
    
    :type Path: string
    :param Path: [REQUIRED]\nThe path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name>\nFor example, to upload the file mlaw.avi to the folder path premium\\canada in the container movies , enter the path premium/canada/mlaw.avi .\nDo not include the container name in this path.\nIf the path includes any folders that don\'t exist yet, the service creates them. For example, suppose you have an existing premium/usa subfolder. If you specify premium/canada , the service creates a canada subfolder in the premium folder. You then have two subfolders, usa and canada , in the premium folder.\nThere is no correlation between the path to the source and the path (folders) in the container in AWS Elemental MediaStore.\nFor more information about folders and how they exist in a container, see the AWS Elemental MediaStore User Guide .\nThe file name is the name that is assigned to the file that you upload. The file can have the same name inside and outside of AWS Elemental MediaStore, or it can have the same name. The file name can include or omit an extension.\n

    :type Range: string
    :param Range: The range bytes of an object to retrieve. For more information about the Range header, see http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.35 . AWS Elemental MediaStore ignores this header for partially uploaded objects that have streaming upload availability.

    :rtype: dict

ReturnsResponse Syntax
{
    'Body': StreamingBody(),
    'CacheControl': 'string',
    'ContentRange': 'string',
    'ContentLength': 123,
    'ContentType': 'string',
    'ETag': 'string',
    'LastModified': datetime(2015, 1, 1),
    'StatusCode': 123
}


Response Structure

(dict) --

Body (StreamingBody) --
The bytes of the object.

CacheControl (string) --
An optional CacheControl header that allows the caller to control the object\'s cache behavior. Headers can be passed in as specified in the HTTP spec at https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.9 .
Headers with a custom user-defined value are also accepted.

ContentRange (string) --
The range of bytes to retrieve.

ContentLength (integer) --
The length of the object in bytes.

ContentType (string) --
The content type of the object.

ETag (string) --
The ETag that represents a unique instance of the object.

LastModified (datetime) --
The date and time that the object was last modified.

StatusCode (integer) --
The HTML status code of the request. Status codes ranging from 200 to 299 indicate success. All other status codes indicate the type of error that occurred.







Exceptions

MediaStoreData.Client.exceptions.ContainerNotFoundException
MediaStoreData.Client.exceptions.ObjectNotFoundException
MediaStoreData.Client.exceptions.RequestedRangeNotSatisfiableException
MediaStoreData.Client.exceptions.InternalServerError


    :return: {
        'Body': StreamingBody(),
        'CacheControl': 'string',
        'ContentRange': 'string',
        'ContentLength': 123,
        'ContentType': 'string',
        'ETag': 'string',
        'LastModified': datetime(2015, 1, 1),
        'StatusCode': 123
    }
    
    
    :returns: 
    MediaStoreData.Client.exceptions.ContainerNotFoundException
    MediaStoreData.Client.exceptions.ObjectNotFoundException
    MediaStoreData.Client.exceptions.RequestedRangeNotSatisfiableException
    MediaStoreData.Client.exceptions.InternalServerError
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_items(Path=None, MaxResults=None, NextToken=None):
    """
    Provides a list of metadata entries about folders and objects in the specified folder.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_items(
        Path='string',
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type Path: string
    :param Path: The path in the container from which to retrieve items. Format: <folder name>/<folder name>/<file name>

    :type MaxResults: integer
    :param MaxResults: The maximum number of results to return per API request. For example, you submit a ListItems request with MaxResults set at 500. Although 2,000 items match your request, the service returns no more than the first 500 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.) The service might return fewer results than the MaxResults value.\nIf MaxResults is not included in the request, the service defaults to pagination with a maximum of 1,000 results per page.\n

    :type NextToken: string
    :param NextToken: The token that identifies which batch of results that you want to see. For example, you submit a ListItems request with MaxResults set at 500. The service returns the first batch of results (up to 500) and a NextToken value. To see the next batch of results, you can submit the ListItems request a second time and specify the NextToken value.\nTokens expire after 15 minutes.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Items': [
        {
            'Name': 'string',
            'Type': 'OBJECT'|'FOLDER',
            'ETag': 'string',
            'LastModified': datetime(2015, 1, 1),
            'ContentType': 'string',
            'ContentLength': 123
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

Items (list) --
The metadata entries for the folders and objects at the requested path.

(dict) --
A metadata entry for a folder or object.

Name (string) --
The name of the item.

Type (string) --
The item type (folder or object).

ETag (string) --
The ETag that represents a unique instance of the item.

LastModified (datetime) --
The date and time that the item was last modified.

ContentType (string) --
The content type of the item.

ContentLength (integer) --
The length of the item in bytes.





NextToken (string) --
The token that can be used in a request to view the next set of results. For example, you submit a ListItems request that matches 2,000 items with MaxResults set at 500. The service returns the first batch of results (up to 500) and a NextToken value that can be used to fetch the next batch of results.







Exceptions

MediaStoreData.Client.exceptions.ContainerNotFoundException
MediaStoreData.Client.exceptions.InternalServerError


    :return: {
        'Items': [
            {
                'Name': 'string',
                'Type': 'OBJECT'|'FOLDER',
                'ETag': 'string',
                'LastModified': datetime(2015, 1, 1),
                'ContentType': 'string',
                'ContentLength': 123
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    MediaStoreData.Client.exceptions.ContainerNotFoundException
    MediaStoreData.Client.exceptions.InternalServerError
    
    """
    pass

def put_object(Body=None, Path=None, ContentType=None, CacheControl=None, StorageClass=None, UploadAvailability=None):
    """
    Uploads an object to the specified path. Object sizes are limited to 25 MB for standard upload availability and 10 MB for streaming upload availability.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.put_object(
        Body=b'bytes'|file,
        Path='string',
        ContentType='string',
        CacheControl='string',
        StorageClass='TEMPORAL',
        UploadAvailability='STANDARD'|'STREAMING'
    )
    
    
    :type Body: bytes or seekable file-like object
    :param Body: [REQUIRED]\nThe bytes to be stored.\n

    :type Path: string
    :param Path: [REQUIRED]\nThe path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name>\nFor example, to upload the file mlaw.avi to the folder path premium\\canada in the container movies , enter the path premium/canada/mlaw.avi .\nDo not include the container name in this path.\nIf the path includes any folders that don\'t exist yet, the service creates them. For example, suppose you have an existing premium/usa subfolder. If you specify premium/canada , the service creates a canada subfolder in the premium folder. You then have two subfolders, usa and canada , in the premium folder.\nThere is no correlation between the path to the source and the path (folders) in the container in AWS Elemental MediaStore.\nFor more information about folders and how they exist in a container, see the AWS Elemental MediaStore User Guide .\nThe file name is the name that is assigned to the file that you upload. The file can have the same name inside and outside of AWS Elemental MediaStore, or it can have the same name. The file name can include or omit an extension.\n

    :type ContentType: string
    :param ContentType: The content type of the object.

    :type CacheControl: string
    :param CacheControl: An optional CacheControl header that allows the caller to control the object\'s cache behavior. Headers can be passed in as specified in the HTTP at https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.9 .\nHeaders with a custom user-defined value are also accepted.\n

    :type StorageClass: string
    :param StorageClass: Indicates the storage class of a Put request. Defaults to high-performance temporal storage class, and objects are persisted into durable storage shortly after being received.

    :type UploadAvailability: string
    :param UploadAvailability: Indicates the availability of an object while it is still uploading. If the value is set to streaming , the object is available for downloading after some initial buffering but before the object is uploaded completely. If the value is set to standard , the object is available for downloading only when it is uploaded completely. The default value for this header is standard .\nTo use this header, you must also set the HTTP Transfer-Encoding header to chunked .\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ContentSHA256': 'string',
    'ETag': 'string',
    'StorageClass': 'TEMPORAL'
}


Response Structure

(dict) --

ContentSHA256 (string) --
The SHA256 digest of the object that is persisted.

ETag (string) --
Unique identifier of the object in the container.

StorageClass (string) --
The storage class where the object was persisted. The class should be \xe2\x80\x9cTemporal\xe2\x80\x9d.







Exceptions

MediaStoreData.Client.exceptions.ContainerNotFoundException
MediaStoreData.Client.exceptions.InternalServerError


    :return: {
        'ContentSHA256': 'string',
        'ETag': 'string',
        'StorageClass': 'TEMPORAL'
    }
    
    
    :returns: 
    MediaStoreData.Client.exceptions.ContainerNotFoundException
    MediaStoreData.Client.exceptions.InternalServerError
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def associate_device_with_placement(projectName=None, placementName=None, deviceId=None, deviceTemplateName=None):
    """
    Associates a physical device with a placement.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.associate_device_with_placement(
        projectName='string',
        placementName='string',
        deviceId='string',
        deviceTemplateName='string'
    )
    
    
    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the project containing the placement in which to associate the device.\n

    :type placementName: string
    :param placementName: [REQUIRED]\nThe name of the placement in which to associate the device.\n

    :type deviceId: string
    :param deviceId: [REQUIRED]\nThe ID of the physical device to be associated with the given placement in the project. Note that a mandatory 4 character prefix is required for all deviceId values.\n

    :type deviceTemplateName: string
    :param deviceTemplateName: [REQUIRED]\nThe device template name to associate with the device ID.\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceConflictException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_placement(placementName=None, projectName=None, attributes=None):
    """
    Creates an empty placement.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_placement(
        placementName='string',
        projectName='string',
        attributes={
            'string': 'string'
        }
    )
    
    
    :type placementName: string
    :param placementName: [REQUIRED]\nThe name of the placement to be created.\n

    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the project in which to create the placement.\n

    :type attributes: dict
    :param attributes: Optional user-defined key/value pairs providing contextual data (such as location or function) for the placement.\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceConflictException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def create_project(projectName=None, description=None, placementTemplate=None, tags=None):
    """
    Creates an empty project with a placement template. A project contains zero or more placements that adhere to the placement template defined in the project.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_project(
        projectName='string',
        description='string',
        placementTemplate={
            'defaultAttributes': {
                'string': 'string'
            },
            'deviceTemplates': {
                'string': {
                    'deviceType': 'string',
                    'callbackOverrides': {
                        'string': 'string'
                    }
                }
            }
        },
        tags={
            'string': 'string'
        }
    )
    
    
    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the project to create.\n

    :type description: string
    :param description: An optional description for the project.

    :type placementTemplate: dict
    :param placementTemplate: The schema defining the placement to be created. A placement template defines placement default attributes and device templates. You cannot add or remove device templates after the project has been created. However, you can update callbackOverrides for the device templates using the UpdateProject API.\n\ndefaultAttributes (dict) --The default attributes (key/value pairs) to be applied to all placements using this template.\n\n(string) --\n(string) --\n\n\n\n\ndeviceTemplates (dict) --An object specifying the DeviceTemplate for all placements using this ( PlacementTemplate ) template.\n\n(string) --\n(dict) --An object representing a device for a placement template (see PlacementTemplate ).\n\ndeviceType (string) --The device type, which currently must be 'button' .\n\ncallbackOverrides (dict) --An optional Lambda function to invoke instead of the default Lambda function provided by the placement template.\n\n(string) --\n(string) --\n\n\n\n\n\n\n\n\n\n\n\n

    :type tags: dict
    :param tags: Optional tags (metadata key/value pairs) to be associated with the project. For example, { {'key1': 'value1', 'key2': 'value2'} } . For more information, see AWS Tagging Strategies .\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceConflictException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def delete_placement(placementName=None, projectName=None):
    """
    Deletes a placement. To delete a placement, it must not have any devices associated with it.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_placement(
        placementName='string',
        projectName='string'
    )
    
    
    :type placementName: string
    :param placementName: [REQUIRED]\nThe name of the empty placement to delete.\n

    :type projectName: string
    :param projectName: [REQUIRED]\nThe project containing the empty placement to delete.\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException
IoT1ClickProjects.Client.exceptions.TooManyRequestsException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def delete_project(projectName=None):
    """
    Deletes a project. To delete a project, it must not have any placements associated with it.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_project(
        projectName='string'
    )
    
    
    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the empty project to delete.\n

    :rtype: dict
ReturnsResponse Syntax{}


Response Structure

(dict) --



Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException
IoT1ClickProjects.Client.exceptions.TooManyRequestsException


    :return: {}
    
    
    :returns: 
    IoT1ClickProjects.Client.exceptions.InternalFailureException
    IoT1ClickProjects.Client.exceptions.InvalidRequestException
    IoT1ClickProjects.Client.exceptions.ResourceNotFoundException
    IoT1ClickProjects.Client.exceptions.TooManyRequestsException
    
    """
    pass

def describe_placement(placementName=None, projectName=None):
    """
    Describes a placement in a project.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_placement(
        placementName='string',
        projectName='string'
    )
    
    
    :type placementName: string
    :param placementName: [REQUIRED]\nThe name of the placement within a project.\n

    :type projectName: string
    :param projectName: [REQUIRED]\nThe project containing the placement to be described.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'placement': {
        'projectName': 'string',
        'placementName': 'string',
        'attributes': {
            'string': 'string'
        },
        'createdDate': datetime(2015, 1, 1),
        'updatedDate': datetime(2015, 1, 1)
    }
}


Response Structure

(dict) --

placement (dict) --
An object describing the placement.

projectName (string) --
The name of the project containing the placement.

placementName (string) --
The name of the placement.

attributes (dict) --
The user-defined attributes associated with the placement.

(string) --
(string) --




createdDate (datetime) --
The date when the placement was initially created, in UNIX epoch time format.

updatedDate (datetime) --
The date when the placement was last updated, in UNIX epoch time format. If the placement was not updated, then createdDate and updatedDate are the same.









Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {
        'placement': {
            'projectName': 'string',
            'placementName': 'string',
            'attributes': {
                'string': 'string'
            },
            'createdDate': datetime(2015, 1, 1),
            'updatedDate': datetime(2015, 1, 1)
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def describe_project(projectName=None):
    """
    Returns an object describing a project.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_project(
        projectName='string'
    )
    
    
    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the project to be described.\n

    :rtype: dict
ReturnsResponse Syntax{
    'project': {
        'arn': 'string',
        'projectName': 'string',
        'description': 'string',
        'createdDate': datetime(2015, 1, 1),
        'updatedDate': datetime(2015, 1, 1),
        'placementTemplate': {
            'defaultAttributes': {
                'string': 'string'
            },
            'deviceTemplates': {
                'string': {
                    'deviceType': 'string',
                    'callbackOverrides': {
                        'string': 'string'
                    }
                }
            }
        },
        'tags': {
            'string': 'string'
        }
    }
}


Response Structure

(dict) --
project (dict) --An object describing the project.

arn (string) --The ARN of the project.

projectName (string) --The name of the project for which to obtain information from.

description (string) --The description of the project.

createdDate (datetime) --The date when the project was originally created, in UNIX epoch time format.

updatedDate (datetime) --The date when the project was last updated, in UNIX epoch time format. If the project was not updated, then createdDate and updatedDate are the same.

placementTemplate (dict) --An object describing the project\'s placement specifications.

defaultAttributes (dict) --The default attributes (key/value pairs) to be applied to all placements using this template.

(string) --
(string) --




deviceTemplates (dict) --An object specifying the  DeviceTemplate for all placements using this ( PlacementTemplate ) template.

(string) --
(dict) --An object representing a device for a placement template (see  PlacementTemplate ).

deviceType (string) --The device type, which currently must be "button" .

callbackOverrides (dict) --An optional Lambda function to invoke instead of the default Lambda function provided by the placement template.

(string) --
(string) --












tags (dict) --The tags (metadata key/value pairs) associated with the project.

(string) --
(string) --











Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {
        'project': {
            'arn': 'string',
            'projectName': 'string',
            'description': 'string',
            'createdDate': datetime(2015, 1, 1),
            'updatedDate': datetime(2015, 1, 1),
            'placementTemplate': {
                'defaultAttributes': {
                    'string': 'string'
                },
                'deviceTemplates': {
                    'string': {
                        'deviceType': 'string',
                        'callbackOverrides': {
                            'string': 'string'
                        }
                    }
                }
            },
            'tags': {
                'string': 'string'
            }
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def disassociate_device_from_placement(projectName=None, placementName=None, deviceTemplateName=None):
    """
    Removes a physical device from a placement.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.disassociate_device_from_placement(
        projectName='string',
        placementName='string',
        deviceTemplateName='string'
    )
    
    
    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the project that contains the placement.\n

    :type placementName: string
    :param placementName: [REQUIRED]\nThe name of the placement that the device should be removed from.\n

    :type deviceTemplateName: string
    :param deviceTemplateName: [REQUIRED]\nThe device ID that should be removed from the placement.\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException
IoT1ClickProjects.Client.exceptions.TooManyRequestsException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_devices_in_placement(projectName=None, placementName=None):
    """
    Returns an object enumerating the devices in a placement.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_devices_in_placement(
        projectName='string',
        placementName='string'
    )
    
    
    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the project containing the placement.\n

    :type placementName: string
    :param placementName: [REQUIRED]\nThe name of the placement to get the devices from.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'devices': {
        'string': 'string'
    }
}


Response Structure

(dict) --

devices (dict) --
An object containing the devices (zero or more) within the placement.

(string) --
(string) --










Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {
        'devices': {
            'string': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_placements(projectName=None, nextToken=None, maxResults=None):
    """
    Lists the placement(s) of a project.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_placements(
        projectName='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type projectName: string
    :param projectName: [REQUIRED]\nThe project containing the placements to be listed.\n

    :type nextToken: string
    :param nextToken: The token to retrieve the next set of results.

    :type maxResults: integer
    :param maxResults: The maximum number of results to return per request. If not set, a default value of 100 is used.

    :rtype: dict

ReturnsResponse Syntax
{
    'placements': [
        {
            'projectName': 'string',
            'placementName': 'string',
            'createdDate': datetime(2015, 1, 1),
            'updatedDate': datetime(2015, 1, 1)
        },
    ],
    'nextToken': 'string'
}


Response Structure

(dict) --

placements (list) --
An object listing the requested placements.

(dict) --
An object providing summary information for a particular placement.

projectName (string) --
The name of the project containing the placement.

placementName (string) --
The name of the placement being summarized.

createdDate (datetime) --
The date when the placement was originally created, in UNIX epoch time format.

updatedDate (datetime) --
The date when the placement was last updated, in UNIX epoch time format. If the placement was not updated, then createdDate and updatedDate are the same.





nextToken (string) --
The token used to retrieve the next set of results - will be effectively empty if there are no further results.







Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {
        'placements': [
            {
                'projectName': 'string',
                'placementName': 'string',
                'createdDate': datetime(2015, 1, 1),
                'updatedDate': datetime(2015, 1, 1)
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    IoT1ClickProjects.Client.exceptions.InternalFailureException
    IoT1ClickProjects.Client.exceptions.InvalidRequestException
    IoT1ClickProjects.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def list_projects(nextToken=None, maxResults=None):
    """
    Lists the AWS IoT 1-Click project(s) associated with your AWS account and region.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_projects(
        nextToken='string',
        maxResults=123
    )
    
    
    :type nextToken: string
    :param nextToken: The token to retrieve the next set of results.

    :type maxResults: integer
    :param maxResults: The maximum number of results to return per request. If not set, a default value of 100 is used.

    :rtype: dict

ReturnsResponse Syntax
{
    'projects': [
        {
            'arn': 'string',
            'projectName': 'string',
            'createdDate': datetime(2015, 1, 1),
            'updatedDate': datetime(2015, 1, 1),
            'tags': {
                'string': 'string'
            }
        },
    ],
    'nextToken': 'string'
}


Response Structure

(dict) --

projects (list) --
An object containing the list of projects.

(dict) --
An object providing summary information for a particular project for an associated AWS account and region.

arn (string) --
The ARN of the project.

projectName (string) --
The name of the project being summarized.

createdDate (datetime) --
The date when the project was originally created, in UNIX epoch time format.

updatedDate (datetime) --
The date when the project was last updated, in UNIX epoch time format. If the project was not updated, then createdDate and updatedDate are the same.

tags (dict) --
The tags (metadata key/value pairs) associated with the project.

(string) --
(string) --








nextToken (string) --
The token used to retrieve the next set of results - will be effectively empty if there are no further results.







Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException


    :return: {
        'projects': [
            {
                'arn': 'string',
                'projectName': 'string',
                'createdDate': datetime(2015, 1, 1),
                'updatedDate': datetime(2015, 1, 1),
                'tags': {
                    'string': 'string'
                }
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def list_tags_for_resource(resourceArn=None):
    """
    Lists the tags (metadata key/value pairs) which you have assigned to the resource.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_tags_for_resource(
        resourceArn='string'
    )
    
    
    :type resourceArn: string
    :param resourceArn: [REQUIRED]\nThe ARN of the resource whose tags you want to list.\n

    :rtype: dict
ReturnsResponse Syntax{
    'tags': {
        'string': 'string'
    }
}


Response Structure

(dict) --
tags (dict) --The tags (metadata key/value pairs) which you have assigned to the resource.

(string) --
(string) --









Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {
        'tags': {
            'string': 'string'
        }
    }
    
    
    :returns: 
    IoT1ClickProjects.Client.exceptions.InternalFailureException
    IoT1ClickProjects.Client.exceptions.InvalidRequestException
    IoT1ClickProjects.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def tag_resource(resourceArn=None, tags=None):
    """
    Creates or modifies tags for a resource. Tags are key/value pairs (metadata) that can be used to manage a resource. For more information, see AWS Tagging Strategies .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.tag_resource(
        resourceArn='string',
        tags={
            'string': 'string'
        }
    )
    
    
    :type resourceArn: string
    :param resourceArn: [REQUIRED]\nThe ARN of the resouce for which tag(s) should be added or modified.\n

    :type tags: dict
    :param tags: [REQUIRED]\nThe new or modifying tag(s) for the resource. See AWS IoT 1-Click Service Limits for the maximum number of tags allowed per resource.\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def untag_resource(resourceArn=None, tagKeys=None):
    """
    Removes one or more tags (metadata key/value pairs) from a resource.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.untag_resource(
        resourceArn='string',
        tagKeys=[
            'string',
        ]
    )
    
    
    :type resourceArn: string
    :param resourceArn: [REQUIRED]\nThe ARN of the resource whose tag you want to remove.\n

    :type tagKeys: list
    :param tagKeys: [REQUIRED]\nThe keys of those tags which you want to remove.\n\n(string) --\n\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def update_placement(placementName=None, projectName=None, attributes=None):
    """
    Updates a placement with the given attributes. To clear an attribute, pass an empty value (i.e., "").
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_placement(
        placementName='string',
        projectName='string',
        attributes={
            'string': 'string'
        }
    )
    
    
    :type placementName: string
    :param placementName: [REQUIRED]\nThe name of the placement to update.\n

    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the project containing the placement to be updated.\n

    :type attributes: dict
    :param attributes: The user-defined object of attributes used to update the placement. The maximum number of key/value pairs is 50.\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException
IoT1ClickProjects.Client.exceptions.TooManyRequestsException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def update_project(projectName=None, description=None, placementTemplate=None):
    """
    Updates a project associated with your AWS account and region. With the exception of device template names, you can pass just the values that need to be updated because the update request will change only the values that are provided. To clear a value, pass the empty string (i.e., "" ).
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_project(
        projectName='string',
        description='string',
        placementTemplate={
            'defaultAttributes': {
                'string': 'string'
            },
            'deviceTemplates': {
                'string': {
                    'deviceType': 'string',
                    'callbackOverrides': {
                        'string': 'string'
                    }
                }
            }
        }
    )
    
    
    :type projectName: string
    :param projectName: [REQUIRED]\nThe name of the project to be updated.\n

    :type description: string
    :param description: An optional user-defined description for the project.

    :type placementTemplate: dict
    :param placementTemplate: An object defining the project update. Once a project has been created, you cannot add device template names to the project. However, for a given placementTemplate , you can update the associated callbackOverrides for the device definition using this API.\n\ndefaultAttributes (dict) --The default attributes (key/value pairs) to be applied to all placements using this template.\n\n(string) --\n(string) --\n\n\n\n\ndeviceTemplates (dict) --An object specifying the DeviceTemplate for all placements using this ( PlacementTemplate ) template.\n\n(string) --\n(dict) --An object representing a device for a placement template (see PlacementTemplate ).\n\ndeviceType (string) --The device type, which currently must be 'button' .\n\ncallbackOverrides (dict) --An optional Lambda function to invoke instead of the default Lambda function provided by the placement template.\n\n(string) --\n(string) --\n\n\n\n\n\n\n\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --




Exceptions

IoT1ClickProjects.Client.exceptions.InternalFailureException
IoT1ClickProjects.Client.exceptions.InvalidRequestException
IoT1ClickProjects.Client.exceptions.ResourceNotFoundException
IoT1ClickProjects.Client.exceptions.TooManyRequestsException


    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def accept_invitation(GraphArn=None):
    """
    Accepts an invitation for the member account to contribute data to a behavior graph. This operation can only be called by an invited member account.
    The request provides the ARN of behavior graph.
    The member account status in the graph must be INVITED .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.accept_invitation(
        GraphArn='string'
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph that the member account is accepting the invitation for.\nThe member account status in the behavior graph must be INVITED .\n

    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_graph():
    """
    Creates a new behavior graph for the calling account, and sets that account as the master account. This operation is called by the account that is enabling Detective.
    Before you try to enable Detective, make sure that your account has been enrolled in Amazon GuardDuty for at least 48 hours. If you do not meet this requirement, you cannot enable Detective. If you do meet the GuardDuty prerequisite, then when you make the request to enable Detective, it checks whether your data volume is within the Detective quota. If it exceeds the quota, then you cannot enable Detective.
    The operation also enables Detective for the calling account in the currently selected Region. It returns the ARN of the new behavior graph.
    An account can only be the master account for one behavior graph within a Region. If the same account calls CreateGraph with the same master account, it always returns the same behavior graph ARN. It does not create a new behavior graph.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_graph()
    
    
    :rtype: dict
ReturnsResponse Syntax{
    'GraphArn': 'string'
}


Response Structure

(dict) --
GraphArn (string) --The ARN of the new behavior graph.






Exceptions

Detective.Client.exceptions.ConflictException
Detective.Client.exceptions.InternalServerException
Detective.Client.exceptions.ServiceQuotaExceededException


    :return: {
        'GraphArn': 'string'
    }
    
    
    """
    pass

def create_members(GraphArn=None, Message=None, Accounts=None):
    """
    Sends a request to invite the specified AWS accounts to be member accounts in the behavior graph. This operation can only be called by the master account for a behavior graph.
    The request provides the behavior graph ARN and the list of accounts to invite.
    The response separates the requested accounts into two lists:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_members(
        GraphArn='string',
        Message='string',
        Accounts=[
            {
                'AccountId': 'string',
                'EmailAddress': 'string'
            },
        ]
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph to invite the member accounts to contribute their data to.\n

    :type Message: string
    :param Message: Customized message text to include in the invitation email message to the invited member accounts.

    :type Accounts: list
    :param Accounts: [REQUIRED]\nThe list of AWS accounts to invite to become member accounts in the behavior graph. For each invited account, the account list contains the account identifier and the AWS account root user email address.\n\n(dict) --An AWS account that is the master of or a member of a behavior graph.\n\nAccountId (string) -- [REQUIRED]The account identifier of the AWS account.\n\nEmailAddress (string) -- [REQUIRED]The AWS account root user email address for the AWS account.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Members': [
        {
            'AccountId': 'string',
            'EmailAddress': 'string',
            'GraphArn': 'string',
            'MasterId': 'string',
            'Status': 'INVITED'|'VERIFICATION_IN_PROGRESS'|'VERIFICATION_FAILED'|'ENABLED'|'ACCEPTED_BUT_DISABLED',
            'DisabledReason': 'VOLUME_TOO_HIGH'|'VOLUME_UNKNOWN',
            'InvitedTime': datetime(2015, 1, 1),
            'UpdatedTime': datetime(2015, 1, 1),
            'PercentOfGraphUtilization': 123.0,
            'PercentOfGraphUtilizationUpdatedTime': datetime(2015, 1, 1)
        },
    ],
    'UnprocessedAccounts': [
        {
            'AccountId': 'string',
            'Reason': 'string'
        },
    ]
}


Response Structure

(dict) --

Members (list) --
The set of member account invitation requests that Detective was able to process. This includes accounts that are being verified, that failed verification, and that passed verification and are being sent an invitation.

(dict) --
Details about a member account that was invited to contribute to a behavior graph.

AccountId (string) --
The AWS account identifier for the member account.

EmailAddress (string) --
The AWS account root user email address for the member account.

GraphArn (string) --
The ARN of the behavior graph that the member account was invited to.

MasterId (string) --
The AWS account identifier of the master account for the behavior graph.

Status (string) --
The current membership status of the member account. The status can have one of the following values:

INVITED - Indicates that the member was sent an invitation but has not yet responded.
VERIFICATION_IN_PROGRESS - Indicates that Detective is verifying that the account identifier and email address provided for the member account match. If they do match, then Detective sends the invitation. If the email address and account identifier don\'t match, then the member cannot be added to the behavior graph.
VERIFICATION_FAILED - Indicates that the account and email address provided for the member account do not match, and Detective did not send an invitation to the account.
ENABLED - Indicates that the member account accepted the invitation to contribute to the behavior graph.
ACCEPTED_BUT_DISABLED - Indicates that the member account accepted the invitation but is prevented from contributing data to the behavior graph. DisabledReason provides the reason why the member account is not enabled.

Member accounts that declined an invitation or that were removed from the behavior graph are not included.

DisabledReason (string) --
For member accounts with a status of ACCEPTED_BUT_DISABLED , the reason that the member account is not enabled.
The reason can have one of the following values:

VOLUME_TOO_HIGH - Indicates that adding the member account would cause the data volume for the behavior graph to be too high.
VOLUME_UNKNOWN - Indicates that Detective is unable to verify the data volume for the member account. This is usually because the member account is not enrolled in Amazon GuardDuty.


InvitedTime (datetime) --
The date and time that Detective sent the invitation to the member account. The value is in milliseconds since the epoch.

UpdatedTime (datetime) --
The date and time that the member account was last updated. The value is in milliseconds since the epoch.

PercentOfGraphUtilization (float) --
The member account data volume as a percentage of the maximum allowed data volume. 0 indicates 0 percent, and 100 indicates 100 percent.
Note that this is not the percentage of the behavior graph data volume.
For example, the data volume for the behavior graph is 80 GB per day. The maximum data volume is 160 GB per day. If the data volume for the member account is 40 GB per day, then PercentOfGraphUtilization is 25. It represents 25% of the maximum allowed data volume.

PercentOfGraphUtilizationUpdatedTime (datetime) --
The date and time when the graph utilization percentage was last updated.





UnprocessedAccounts (list) --
The list of accounts for which Detective was unable to process the invitation request. For each account, the list provides the reason why the request could not be processed. The list includes accounts that are already member accounts in the behavior graph.

(dict) --
A member account that was included in a request but for which the request could not be processed.

AccountId (string) --
The AWS account identifier of the member account that was not processed.

Reason (string) --
The reason that the member account request could not be processed.











Exceptions

Detective.Client.exceptions.InternalServerException
Detective.Client.exceptions.ResourceNotFoundException
Detective.Client.exceptions.ValidationException
Detective.Client.exceptions.ServiceQuotaExceededException


    :return: {
        'Members': [
            {
                'AccountId': 'string',
                'EmailAddress': 'string',
                'GraphArn': 'string',
                'MasterId': 'string',
                'Status': 'INVITED'|'VERIFICATION_IN_PROGRESS'|'VERIFICATION_FAILED'|'ENABLED'|'ACCEPTED_BUT_DISABLED',
                'DisabledReason': 'VOLUME_TOO_HIGH'|'VOLUME_UNKNOWN',
                'InvitedTime': datetime(2015, 1, 1),
                'UpdatedTime': datetime(2015, 1, 1),
                'PercentOfGraphUtilization': 123.0,
                'PercentOfGraphUtilizationUpdatedTime': datetime(2015, 1, 1)
            },
        ],
        'UnprocessedAccounts': [
            {
                'AccountId': 'string',
                'Reason': 'string'
            },
        ]
    }
    
    
    :returns: 
    GraphArn (string) -- [REQUIRED]
    The ARN of the behavior graph to invite the member accounts to contribute their data to.
    
    Message (string) -- Customized message text to include in the invitation email message to the invited member accounts.
    Accounts (list) -- [REQUIRED]
    The list of AWS accounts to invite to become member accounts in the behavior graph. For each invited account, the account list contains the account identifier and the AWS account root user email address.
    
    (dict) --An AWS account that is the master of or a member of a behavior graph.
    
    AccountId (string) -- [REQUIRED]The account identifier of the AWS account.
    
    EmailAddress (string) -- [REQUIRED]The AWS account root user email address for the AWS account.
    
    
    
    
    
    
    """
    pass

def delete_graph(GraphArn=None):
    """
    Disables the specified behavior graph and queues it to be deleted. This operation removes the graph from each member account\'s list of behavior graphs.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_graph(
        GraphArn='string'
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph to disable.\n

    """
    pass

def delete_members(GraphArn=None, AccountIds=None):
    """
    Deletes one or more member accounts from the master account behavior graph. This operation can only be called by a Detective master account. That account cannot use DeleteMembers to delete their own account from the behavior graph. To disable a behavior graph, the master account uses the DeleteGraph API method.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_members(
        GraphArn='string',
        AccountIds=[
            'string',
        ]
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph to delete members from.\n

    :type AccountIds: list
    :param AccountIds: [REQUIRED]\nThe list of AWS account identifiers for the member accounts to delete from the behavior graph.\n\n(string) --\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'AccountIds': [
        'string',
    ],
    'UnprocessedAccounts': [
        {
            'AccountId': 'string',
            'Reason': 'string'
        },
    ]
}


Response Structure

(dict) --

AccountIds (list) --
The list of AWS account identifiers for the member accounts that Detective successfully deleted from the behavior graph.

(string) --


UnprocessedAccounts (list) --
The list of member accounts that Detective was not able to delete from the behavior graph. For each member account, provides the reason that the deletion could not be processed.

(dict) --
A member account that was included in a request but for which the request could not be processed.

AccountId (string) --
The AWS account identifier of the member account that was not processed.

Reason (string) --
The reason that the member account request could not be processed.











Exceptions

Detective.Client.exceptions.ConflictException
Detective.Client.exceptions.InternalServerException
Detective.Client.exceptions.ResourceNotFoundException
Detective.Client.exceptions.ValidationException


    :return: {
        'AccountIds': [
            'string',
        ],
        'UnprocessedAccounts': [
            {
                'AccountId': 'string',
                'Reason': 'string'
            },
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def disassociate_membership(GraphArn=None):
    """
    Removes the member account from the specified behavior graph. This operation can only be called by a member account that has the ENABLED status.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.disassociate_membership(
        GraphArn='string'
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph to remove the member account from.\nThe member account\'s member status in the behavior graph must be ENABLED .\n

    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_members(GraphArn=None, AccountIds=None):
    """
    Returns the membership details for specified member accounts for a behavior graph.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_members(
        GraphArn='string',
        AccountIds=[
            'string',
        ]
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph for which to request the member details.\n

    :type AccountIds: list
    :param AccountIds: [REQUIRED]\nThe list of AWS account identifiers for the member account for which to return member details.\nYou cannot use GetMembers to retrieve information about member accounts that were removed from the behavior graph.\n\n(string) --\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MemberDetails': [
        {
            'AccountId': 'string',
            'EmailAddress': 'string',
            'GraphArn': 'string',
            'MasterId': 'string',
            'Status': 'INVITED'|'VERIFICATION_IN_PROGRESS'|'VERIFICATION_FAILED'|'ENABLED'|'ACCEPTED_BUT_DISABLED',
            'DisabledReason': 'VOLUME_TOO_HIGH'|'VOLUME_UNKNOWN',
            'InvitedTime': datetime(2015, 1, 1),
            'UpdatedTime': datetime(2015, 1, 1),
            'PercentOfGraphUtilization': 123.0,
            'PercentOfGraphUtilizationUpdatedTime': datetime(2015, 1, 1)
        },
    ],
    'UnprocessedAccounts': [
        {
            'AccountId': 'string',
            'Reason': 'string'
        },
    ]
}


Response Structure

(dict) --

MemberDetails (list) --
The member account details that Detective is returning in response to the request.

(dict) --
Details about a member account that was invited to contribute to a behavior graph.

AccountId (string) --
The AWS account identifier for the member account.

EmailAddress (string) --
The AWS account root user email address for the member account.

GraphArn (string) --
The ARN of the behavior graph that the member account was invited to.

MasterId (string) --
The AWS account identifier of the master account for the behavior graph.

Status (string) --
The current membership status of the member account. The status can have one of the following values:

INVITED - Indicates that the member was sent an invitation but has not yet responded.
VERIFICATION_IN_PROGRESS - Indicates that Detective is verifying that the account identifier and email address provided for the member account match. If they do match, then Detective sends the invitation. If the email address and account identifier don\'t match, then the member cannot be added to the behavior graph.
VERIFICATION_FAILED - Indicates that the account and email address provided for the member account do not match, and Detective did not send an invitation to the account.
ENABLED - Indicates that the member account accepted the invitation to contribute to the behavior graph.
ACCEPTED_BUT_DISABLED - Indicates that the member account accepted the invitation but is prevented from contributing data to the behavior graph. DisabledReason provides the reason why the member account is not enabled.

Member accounts that declined an invitation or that were removed from the behavior graph are not included.

DisabledReason (string) --
For member accounts with a status of ACCEPTED_BUT_DISABLED , the reason that the member account is not enabled.
The reason can have one of the following values:

VOLUME_TOO_HIGH - Indicates that adding the member account would cause the data volume for the behavior graph to be too high.
VOLUME_UNKNOWN - Indicates that Detective is unable to verify the data volume for the member account. This is usually because the member account is not enrolled in Amazon GuardDuty.


InvitedTime (datetime) --
The date and time that Detective sent the invitation to the member account. The value is in milliseconds since the epoch.

UpdatedTime (datetime) --
The date and time that the member account was last updated. The value is in milliseconds since the epoch.

PercentOfGraphUtilization (float) --
The member account data volume as a percentage of the maximum allowed data volume. 0 indicates 0 percent, and 100 indicates 100 percent.
Note that this is not the percentage of the behavior graph data volume.
For example, the data volume for the behavior graph is 80 GB per day. The maximum data volume is 160 GB per day. If the data volume for the member account is 40 GB per day, then PercentOfGraphUtilization is 25. It represents 25% of the maximum allowed data volume.

PercentOfGraphUtilizationUpdatedTime (datetime) --
The date and time when the graph utilization percentage was last updated.





UnprocessedAccounts (list) --
The requested member accounts for which Detective was unable to return member details.
For each account, provides the reason why the request could not be processed.

(dict) --
A member account that was included in a request but for which the request could not be processed.

AccountId (string) --
The AWS account identifier of the member account that was not processed.

Reason (string) --
The reason that the member account request could not be processed.











Exceptions

Detective.Client.exceptions.InternalServerException
Detective.Client.exceptions.ResourceNotFoundException
Detective.Client.exceptions.ValidationException


    :return: {
        'MemberDetails': [
            {
                'AccountId': 'string',
                'EmailAddress': 'string',
                'GraphArn': 'string',
                'MasterId': 'string',
                'Status': 'INVITED'|'VERIFICATION_IN_PROGRESS'|'VERIFICATION_FAILED'|'ENABLED'|'ACCEPTED_BUT_DISABLED',
                'DisabledReason': 'VOLUME_TOO_HIGH'|'VOLUME_UNKNOWN',
                'InvitedTime': datetime(2015, 1, 1),
                'UpdatedTime': datetime(2015, 1, 1),
                'PercentOfGraphUtilization': 123.0,
                'PercentOfGraphUtilizationUpdatedTime': datetime(2015, 1, 1)
            },
        ],
        'UnprocessedAccounts': [
            {
                'AccountId': 'string',
                'Reason': 'string'
            },
        ]
    }
    
    
    :returns: 
    INVITED - Indicates that the member was sent an invitation but has not yet responded.
    VERIFICATION_IN_PROGRESS - Indicates that Detective is verifying that the account identifier and email address provided for the member account match. If they do match, then Detective sends the invitation. If the email address and account identifier don\'t match, then the member cannot be added to the behavior graph.
    VERIFICATION_FAILED - Indicates that the account and email address provided for the member account do not match, and Detective did not send an invitation to the account.
    ENABLED - Indicates that the member account accepted the invitation to contribute to the behavior graph.
    ACCEPTED_BUT_DISABLED - Indicates that the member account accepted the invitation but is prevented from contributing data to the behavior graph. DisabledReason provides the reason why the member account is not enabled.
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_graphs(NextToken=None, MaxResults=None):
    """
    Returns the list of behavior graphs that the calling account is a master of. This operation can only be called by a master account.
    Because an account can currently only be the master of one behavior graph within a Region, the results always contain a single graph.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_graphs(
        NextToken='string',
        MaxResults=123
    )
    
    
    :type NextToken: string
    :param NextToken: For requests to get the next page of results, the pagination token that was returned with the previous set of results. The initial request does not include a pagination token.

    :type MaxResults: integer
    :param MaxResults: The maximum number of graphs to return at a time. The total must be less than the overall limit on the number of results to return, which is currently 200.

    :rtype: dict

ReturnsResponse Syntax
{
    'GraphList': [
        {
            'Arn': 'string',
            'CreatedTime': datetime(2015, 1, 1)
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

GraphList (list) --
A list of behavior graphs that the account is a master for.

(dict) --
A behavior graph in Detective.

Arn (string) --
The ARN of the behavior graph.

CreatedTime (datetime) --
The date and time that the behavior graph was created. The value is in milliseconds since the epoch.





NextToken (string) --
If there are more behavior graphs remaining in the results, then this is the pagination token to use to request the next page of behavior graphs.







Exceptions

Detective.Client.exceptions.InternalServerException
Detective.Client.exceptions.ValidationException


    :return: {
        'GraphList': [
            {
                'Arn': 'string',
                'CreatedTime': datetime(2015, 1, 1)
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    Detective.Client.exceptions.InternalServerException
    Detective.Client.exceptions.ValidationException
    
    """
    pass

def list_invitations(NextToken=None, MaxResults=None):
    """
    Retrieves the list of open and accepted behavior graph invitations for the member account. This operation can only be called by a member account.
    Open invitations are invitations that the member account has not responded to.
    The results do not include behavior graphs for which the member account declined the invitation. The results also do not include behavior graphs that the member account resigned from or was removed from.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_invitations(
        NextToken='string',
        MaxResults=123
    )
    
    
    :type NextToken: string
    :param NextToken: For requests to retrieve the next page of results, the pagination token that was returned with the previous page of results. The initial request does not include a pagination token.

    :type MaxResults: integer
    :param MaxResults: The maximum number of behavior graph invitations to return in the response. The total must be less than the overall limit on the number of results to return, which is currently 200.

    :rtype: dict

ReturnsResponse Syntax
{
    'Invitations': [
        {
            'AccountId': 'string',
            'EmailAddress': 'string',
            'GraphArn': 'string',
            'MasterId': 'string',
            'Status': 'INVITED'|'VERIFICATION_IN_PROGRESS'|'VERIFICATION_FAILED'|'ENABLED'|'ACCEPTED_BUT_DISABLED',
            'DisabledReason': 'VOLUME_TOO_HIGH'|'VOLUME_UNKNOWN',
            'InvitedTime': datetime(2015, 1, 1),
            'UpdatedTime': datetime(2015, 1, 1),
            'PercentOfGraphUtilization': 123.0,
            'PercentOfGraphUtilizationUpdatedTime': datetime(2015, 1, 1)
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

Invitations (list) --
The list of behavior graphs for which the member account has open or accepted invitations.

(dict) --
Details about a member account that was invited to contribute to a behavior graph.

AccountId (string) --
The AWS account identifier for the member account.

EmailAddress (string) --
The AWS account root user email address for the member account.

GraphArn (string) --
The ARN of the behavior graph that the member account was invited to.

MasterId (string) --
The AWS account identifier of the master account for the behavior graph.

Status (string) --
The current membership status of the member account. The status can have one of the following values:

INVITED - Indicates that the member was sent an invitation but has not yet responded.
VERIFICATION_IN_PROGRESS - Indicates that Detective is verifying that the account identifier and email address provided for the member account match. If they do match, then Detective sends the invitation. If the email address and account identifier don\'t match, then the member cannot be added to the behavior graph.
VERIFICATION_FAILED - Indicates that the account and email address provided for the member account do not match, and Detective did not send an invitation to the account.
ENABLED - Indicates that the member account accepted the invitation to contribute to the behavior graph.
ACCEPTED_BUT_DISABLED - Indicates that the member account accepted the invitation but is prevented from contributing data to the behavior graph. DisabledReason provides the reason why the member account is not enabled.

Member accounts that declined an invitation or that were removed from the behavior graph are not included.

DisabledReason (string) --
For member accounts with a status of ACCEPTED_BUT_DISABLED , the reason that the member account is not enabled.
The reason can have one of the following values:

VOLUME_TOO_HIGH - Indicates that adding the member account would cause the data volume for the behavior graph to be too high.
VOLUME_UNKNOWN - Indicates that Detective is unable to verify the data volume for the member account. This is usually because the member account is not enrolled in Amazon GuardDuty.


InvitedTime (datetime) --
The date and time that Detective sent the invitation to the member account. The value is in milliseconds since the epoch.

UpdatedTime (datetime) --
The date and time that the member account was last updated. The value is in milliseconds since the epoch.

PercentOfGraphUtilization (float) --
The member account data volume as a percentage of the maximum allowed data volume. 0 indicates 0 percent, and 100 indicates 100 percent.
Note that this is not the percentage of the behavior graph data volume.
For example, the data volume for the behavior graph is 80 GB per day. The maximum data volume is 160 GB per day. If the data volume for the member account is 40 GB per day, then PercentOfGraphUtilization is 25. It represents 25% of the maximum allowed data volume.

PercentOfGraphUtilizationUpdatedTime (datetime) --
The date and time when the graph utilization percentage was last updated.





NextToken (string) --
If there are more behavior graphs remaining in the results, then this is the pagination token to use to request the next page of behavior graphs.







Exceptions

Detective.Client.exceptions.InternalServerException
Detective.Client.exceptions.ValidationException


    :return: {
        'Invitations': [
            {
                'AccountId': 'string',
                'EmailAddress': 'string',
                'GraphArn': 'string',
                'MasterId': 'string',
                'Status': 'INVITED'|'VERIFICATION_IN_PROGRESS'|'VERIFICATION_FAILED'|'ENABLED'|'ACCEPTED_BUT_DISABLED',
                'DisabledReason': 'VOLUME_TOO_HIGH'|'VOLUME_UNKNOWN',
                'InvitedTime': datetime(2015, 1, 1),
                'UpdatedTime': datetime(2015, 1, 1),
                'PercentOfGraphUtilization': 123.0,
                'PercentOfGraphUtilizationUpdatedTime': datetime(2015, 1, 1)
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    INVITED - Indicates that the member was sent an invitation but has not yet responded.
    VERIFICATION_IN_PROGRESS - Indicates that Detective is verifying that the account identifier and email address provided for the member account match. If they do match, then Detective sends the invitation. If the email address and account identifier don\'t match, then the member cannot be added to the behavior graph.
    VERIFICATION_FAILED - Indicates that the account and email address provided for the member account do not match, and Detective did not send an invitation to the account.
    ENABLED - Indicates that the member account accepted the invitation to contribute to the behavior graph.
    ACCEPTED_BUT_DISABLED - Indicates that the member account accepted the invitation but is prevented from contributing data to the behavior graph. DisabledReason provides the reason why the member account is not enabled.
    
    """
    pass

def list_members(GraphArn=None, NextToken=None, MaxResults=None):
    """
    Retrieves the list of member accounts for a behavior graph. Does not return member accounts that were removed from the behavior graph.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_members(
        GraphArn='string',
        NextToken='string',
        MaxResults=123
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph for which to retrieve the list of member accounts.\n

    :type NextToken: string
    :param NextToken: For requests to retrieve the next page of member account results, the pagination token that was returned with the previous page of results. The initial request does not include a pagination token.

    :type MaxResults: integer
    :param MaxResults: The maximum number of member accounts to include in the response. The total must be less than the overall limit on the number of results to return, which is currently 200.

    :rtype: dict

ReturnsResponse Syntax
{
    'MemberDetails': [
        {
            'AccountId': 'string',
            'EmailAddress': 'string',
            'GraphArn': 'string',
            'MasterId': 'string',
            'Status': 'INVITED'|'VERIFICATION_IN_PROGRESS'|'VERIFICATION_FAILED'|'ENABLED'|'ACCEPTED_BUT_DISABLED',
            'DisabledReason': 'VOLUME_TOO_HIGH'|'VOLUME_UNKNOWN',
            'InvitedTime': datetime(2015, 1, 1),
            'UpdatedTime': datetime(2015, 1, 1),
            'PercentOfGraphUtilization': 123.0,
            'PercentOfGraphUtilizationUpdatedTime': datetime(2015, 1, 1)
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

MemberDetails (list) --
The list of member accounts in the behavior graph.
The results include member accounts that did not pass verification and member accounts that have not yet accepted the invitation to the behavior graph. The results do not include member accounts that were removed from the behavior graph.

(dict) --
Details about a member account that was invited to contribute to a behavior graph.

AccountId (string) --
The AWS account identifier for the member account.

EmailAddress (string) --
The AWS account root user email address for the member account.

GraphArn (string) --
The ARN of the behavior graph that the member account was invited to.

MasterId (string) --
The AWS account identifier of the master account for the behavior graph.

Status (string) --
The current membership status of the member account. The status can have one of the following values:

INVITED - Indicates that the member was sent an invitation but has not yet responded.
VERIFICATION_IN_PROGRESS - Indicates that Detective is verifying that the account identifier and email address provided for the member account match. If they do match, then Detective sends the invitation. If the email address and account identifier don\'t match, then the member cannot be added to the behavior graph.
VERIFICATION_FAILED - Indicates that the account and email address provided for the member account do not match, and Detective did not send an invitation to the account.
ENABLED - Indicates that the member account accepted the invitation to contribute to the behavior graph.
ACCEPTED_BUT_DISABLED - Indicates that the member account accepted the invitation but is prevented from contributing data to the behavior graph. DisabledReason provides the reason why the member account is not enabled.

Member accounts that declined an invitation or that were removed from the behavior graph are not included.

DisabledReason (string) --
For member accounts with a status of ACCEPTED_BUT_DISABLED , the reason that the member account is not enabled.
The reason can have one of the following values:

VOLUME_TOO_HIGH - Indicates that adding the member account would cause the data volume for the behavior graph to be too high.
VOLUME_UNKNOWN - Indicates that Detective is unable to verify the data volume for the member account. This is usually because the member account is not enrolled in Amazon GuardDuty.


InvitedTime (datetime) --
The date and time that Detective sent the invitation to the member account. The value is in milliseconds since the epoch.

UpdatedTime (datetime) --
The date and time that the member account was last updated. The value is in milliseconds since the epoch.

PercentOfGraphUtilization (float) --
The member account data volume as a percentage of the maximum allowed data volume. 0 indicates 0 percent, and 100 indicates 100 percent.
Note that this is not the percentage of the behavior graph data volume.
For example, the data volume for the behavior graph is 80 GB per day. The maximum data volume is 160 GB per day. If the data volume for the member account is 40 GB per day, then PercentOfGraphUtilization is 25. It represents 25% of the maximum allowed data volume.

PercentOfGraphUtilizationUpdatedTime (datetime) --
The date and time when the graph utilization percentage was last updated.





NextToken (string) --
If there are more member accounts remaining in the results, then this is the pagination token to use to request the next page of member accounts.







Exceptions

Detective.Client.exceptions.InternalServerException
Detective.Client.exceptions.ResourceNotFoundException
Detective.Client.exceptions.ValidationException


    :return: {
        'MemberDetails': [
            {
                'AccountId': 'string',
                'EmailAddress': 'string',
                'GraphArn': 'string',
                'MasterId': 'string',
                'Status': 'INVITED'|'VERIFICATION_IN_PROGRESS'|'VERIFICATION_FAILED'|'ENABLED'|'ACCEPTED_BUT_DISABLED',
                'DisabledReason': 'VOLUME_TOO_HIGH'|'VOLUME_UNKNOWN',
                'InvitedTime': datetime(2015, 1, 1),
                'UpdatedTime': datetime(2015, 1, 1),
                'PercentOfGraphUtilization': 123.0,
                'PercentOfGraphUtilizationUpdatedTime': datetime(2015, 1, 1)
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    INVITED - Indicates that the member was sent an invitation but has not yet responded.
    VERIFICATION_IN_PROGRESS - Indicates that Detective is verifying that the account identifier and email address provided for the member account match. If they do match, then Detective sends the invitation. If the email address and account identifier don\'t match, then the member cannot be added to the behavior graph.
    VERIFICATION_FAILED - Indicates that the account and email address provided for the member account do not match, and Detective did not send an invitation to the account.
    ENABLED - Indicates that the member account accepted the invitation to contribute to the behavior graph.
    ACCEPTED_BUT_DISABLED - Indicates that the member account accepted the invitation but is prevented from contributing data to the behavior graph. DisabledReason provides the reason why the member account is not enabled.
    
    """
    pass

def reject_invitation(GraphArn=None):
    """
    Rejects an invitation to contribute the account data to a behavior graph. This operation must be called by a member account that has the INVITED status.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.reject_invitation(
        GraphArn='string'
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph to reject the invitation to.\nThe member account\'s current member status in the behavior graph must be INVITED .\n

    """
    pass

def start_monitoring_member(GraphArn=None, AccountId=None):
    """
    Sends a request to enable data ingest for a member account that has a status of ACCEPTED_BUT_DISABLED .
    For valid member accounts, the status is updated as follows.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.start_monitoring_member(
        GraphArn='string',
        AccountId='string'
    )
    
    
    :type GraphArn: string
    :param GraphArn: [REQUIRED]\nThe ARN of the behavior graph.\n

    :type AccountId: string
    :param AccountId: [REQUIRED]\nThe account ID of the member account to try to enable.\nThe account must be an invited member account with a status of ACCEPTED_BUT_DISABLED .\n

    :returns: 
    GraphArn (string) -- [REQUIRED]
    The ARN of the behavior graph.
    
    AccountId (string) -- [REQUIRED]
    The account ID of the member account to try to enable.
    The account must be an invited member account with a status of ACCEPTED_BUT_DISABLED .
    
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_home_region_control(HomeRegion=None, Target=None, DryRun=None):
    """
    This API sets up the home region for the calling account only.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_home_region_control(
        HomeRegion='string',
        Target={
            'Type': 'ACCOUNT',
            'Id': 'string'
        },
        DryRun=True|False
    )
    
    
    :type HomeRegion: string
    :param HomeRegion: [REQUIRED]\nThe name of the home region of the calling account.\n

    :type Target: dict
    :param Target: [REQUIRED]\nThe account for which this command sets up a home region control. The Target is always of type ACCOUNT .\n\nType (string) -- [REQUIRED]The target type is always an ACCOUNT .\n\nId (string) --The TargetID is a 12-character identifier of the ACCOUNT for which the control was created. (This must be the current account.)\n\n\n

    :type DryRun: boolean
    :param DryRun: Optional Boolean flag to indicate whether any effect should take place. It tests whether the caller has permission to make the call.

    :rtype: dict

ReturnsResponse Syntax
{
    'HomeRegionControl': {
        'ControlId': 'string',
        'HomeRegion': 'string',
        'Target': {
            'Type': 'ACCOUNT',
            'Id': 'string'
        },
        'RequestedTime': datetime(2015, 1, 1)
    }
}


Response Structure

(dict) --

HomeRegionControl (dict) --
This object is the HomeRegionControl object that\'s returned by a successful call to CreateHomeRegionControl .

ControlId (string) --
A unique identifier that\'s generated for each home region control. It\'s always a string that begins with "hrc-" followed by 12 lowercase letters and numbers.

HomeRegion (string) --
The AWS Region that\'s been set as home region. For example, "us-west-2" or "eu-central-1" are valid home regions.

Target (dict) --
The target parameter specifies the identifier to which the home region is applied, which is always an ACCOUNT . It applies the home region to the current ACCOUNT .

Type (string) --
The target type is always an ACCOUNT .

Id (string) --
The TargetID is a 12-character identifier of the ACCOUNT for which the control was created. (This must be the current account.)



RequestedTime (datetime) --
A timestamp representing the time when the customer called CreateHomeregionControl and set the home region for the account.









Exceptions

MigrationHubConfig.Client.exceptions.InternalServerError
MigrationHubConfig.Client.exceptions.ServiceUnavailableException
MigrationHubConfig.Client.exceptions.AccessDeniedException
MigrationHubConfig.Client.exceptions.ThrottlingException
MigrationHubConfig.Client.exceptions.DryRunOperation
MigrationHubConfig.Client.exceptions.InvalidInputException


    :return: {
        'HomeRegionControl': {
            'ControlId': 'string',
            'HomeRegion': 'string',
            'Target': {
                'Type': 'ACCOUNT',
                'Id': 'string'
            },
            'RequestedTime': datetime(2015, 1, 1)
        }
    }
    
    
    :returns: 
    MigrationHubConfig.Client.exceptions.InternalServerError
    MigrationHubConfig.Client.exceptions.ServiceUnavailableException
    MigrationHubConfig.Client.exceptions.AccessDeniedException
    MigrationHubConfig.Client.exceptions.ThrottlingException
    MigrationHubConfig.Client.exceptions.DryRunOperation
    MigrationHubConfig.Client.exceptions.InvalidInputException
    
    """
    pass

def describe_home_region_controls(ControlId=None, HomeRegion=None, Target=None, MaxResults=None, NextToken=None):
    """
    This API permits filtering on the ControlId and HomeRegion fields.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_home_region_controls(
        ControlId='string',
        HomeRegion='string',
        Target={
            'Type': 'ACCOUNT',
            'Id': 'string'
        },
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type ControlId: string
    :param ControlId: The ControlID is a unique identifier string of your HomeRegionControl object.

    :type HomeRegion: string
    :param HomeRegion: The name of the home region you\'d like to view.

    :type Target: dict
    :param Target: The target parameter specifies the identifier to which the home region is applied, which is always of type ACCOUNT . It applies the home region to the current ACCOUNT .\n\nType (string) -- [REQUIRED]The target type is always an ACCOUNT .\n\nId (string) --The TargetID is a 12-character identifier of the ACCOUNT for which the control was created. (This must be the current account.)\n\n\n

    :type MaxResults: integer
    :param MaxResults: The maximum number of filtering results to display per page.

    :type NextToken: string
    :param NextToken: If a NextToken was returned by a previous call, more results are available. To retrieve the next page of results, make the call again using the returned token in NextToken .

    :rtype: dict

ReturnsResponse Syntax
{
    'HomeRegionControls': [
        {
            'ControlId': 'string',
            'HomeRegion': 'string',
            'Target': {
                'Type': 'ACCOUNT',
                'Id': 'string'
            },
            'RequestedTime': datetime(2015, 1, 1)
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

HomeRegionControls (list) --
An array that contains your HomeRegionControl objects.

(dict) --
A home region control is an object that specifies the home region for an account, with some additional information. It contains a target (always of type ACCOUNT ), an ID, and a time at which the home region was set.

ControlId (string) --
A unique identifier that\'s generated for each home region control. It\'s always a string that begins with "hrc-" followed by 12 lowercase letters and numbers.

HomeRegion (string) --
The AWS Region that\'s been set as home region. For example, "us-west-2" or "eu-central-1" are valid home regions.

Target (dict) --
The target parameter specifies the identifier to which the home region is applied, which is always an ACCOUNT . It applies the home region to the current ACCOUNT .

Type (string) --
The target type is always an ACCOUNT .

Id (string) --
The TargetID is a 12-character identifier of the ACCOUNT for which the control was created. (This must be the current account.)



RequestedTime (datetime) --
A timestamp representing the time when the customer called CreateHomeregionControl and set the home region for the account.





NextToken (string) --
If a NextToken was returned by a previous call, more results are available. To retrieve the next page of results, make the call again using the returned token in NextToken .







Exceptions

MigrationHubConfig.Client.exceptions.InternalServerError
MigrationHubConfig.Client.exceptions.ServiceUnavailableException
MigrationHubConfig.Client.exceptions.AccessDeniedException
MigrationHubConfig.Client.exceptions.ThrottlingException
MigrationHubConfig.Client.exceptions.InvalidInputException


    :return: {
        'HomeRegionControls': [
            {
                'ControlId': 'string',
                'HomeRegion': 'string',
                'Target': {
                    'Type': 'ACCOUNT',
                    'Id': 'string'
                },
                'RequestedTime': datetime(2015, 1, 1)
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    MigrationHubConfig.Client.exceptions.InternalServerError
    MigrationHubConfig.Client.exceptions.ServiceUnavailableException
    MigrationHubConfig.Client.exceptions.AccessDeniedException
    MigrationHubConfig.Client.exceptions.ThrottlingException
    MigrationHubConfig.Client.exceptions.InvalidInputException
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_home_region():
    """
    Returns the calling account\xe2\x80\x99s home region, if configured. This API is used by other AWS services to determine the regional endpoint for calling AWS Application Discovery Service and Migration Hub. You must call GetHomeRegion at least once before you call any other AWS Application Discovery Service and AWS Migration Hub APIs, to obtain the account\'s Migration Hub home region.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_home_region()
    
    
    :rtype: dict
ReturnsResponse Syntax{
    'HomeRegion': 'string'
}


Response Structure

(dict) --
HomeRegion (string) --The name of the home region of the calling account.






Exceptions

MigrationHubConfig.Client.exceptions.InternalServerError
MigrationHubConfig.Client.exceptions.ServiceUnavailableException
MigrationHubConfig.Client.exceptions.AccessDeniedException
MigrationHubConfig.Client.exceptions.ThrottlingException
MigrationHubConfig.Client.exceptions.InvalidInputException


    :return: {
        'HomeRegion': 'string'
    }
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

